# -*- coding: utf-8 -*-
#
# File: test_bodyfactory.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher <hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'

import unittest
from zope import component
from zope.component import adapter

from mailtoplone.base.tests.base import MailToPloneBaseTestCase
from mailtoplone.base.interfaces import IBodyFactory

MULTIONEPLAIN="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/plain;

plain content
--next
Content-Type: text/calendar;

other content
--next--
"""

MULTITWOPLAIN="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/plain; charset=xy-charset;

plain content1
--next
Content-Type: text/plain;

plain content2
--next--
"""

MULTIONEHTML="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/plain;

plain content
--next
Content-Type: text/html; charset=iso-8859-1;

html content
--next--
"""

MULTITWOHTML="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/html;

html content1
--next
Content-Type: text/html;

html content2
--next--
"""

MULTIONERFC822="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/rfc822;

rfc822 content
--next
Content-Type: text/calendar;

other content
--next--
"""

MULTITWORFC822="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/rfc822;

rfc822 content1
--next
Content-Type: text/rfc822;

rfc822 content2
--next--
"""

MULTIOTHER="""MIME-Version: 1.0
Content-Type: multipart/mixed;
	boundary="next"

--next
Content-Type: text/calendar;

other content1
--next
Content-Type: video/mpeg;

other content2
--next--
"""

class TestBodyFactory(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.setRoles(('Manager',))
        self.factory = component.queryUtility(IBodyFactory)

    def test_multioneplain(self):
        body, content_type, charset = self.factory(MULTIONEPLAIN)
        self.assertEquals(body,'plain content')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,None)

    def test_multitwoplain(self):
        body, content_type, charset = self.factory(MULTITWOPLAIN)
        self.assertEquals(body,'plain content1')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,'xy-charset')

    def test_multionehtml(self):
        body, content_type, charset= self.factory(MULTIONEHTML)
        self.assertEquals(body,'html content')
        self.assertEquals(content_type,'text/html')
        self.assertEquals(charset,'iso-8859-1')

    def test_multitwohtml(self):
        body, content_type, charset = self.factory(MULTITWOHTML)
        self.assertEquals(body,'html content1')
        self.assertEquals(content_type,'text/html')
        self.assertEquals(charset,None)

    def test_multionerfc822(self):
        body, content_type, charset = self.factory(MULTIONERFC822)
        self.assertEquals(body,'rfc822 content')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,None)

    def test_multitworfc822(self):
        body, content_type, charset = self.factory(MULTITWORFC822)
        self.assertEquals(body,'rfc822 content1')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,None)

    def test_multiother(self):
        body, content_type, charset = self.factory(MULTIOTHER)
        self.assertEquals(body,'')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,None)

    def test_noemail(self):
        body, content_type, charset = self.factory("")
        self.assertEquals(body,'')
        self.assertEquals(content_type,'text/plain')
        self.assertEquals(charset,None)

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestBodyFactory))
    return suite

# vim: set ft=python ts=4 sw=4 expandtab :




# -*- coding: utf-8 -*-
#
# File: test_eventfactory_examples.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher <hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'

import unittest
import os

from zope import component

from mailtoplone.base.tests.base import MailToPloneBaseTestCase
from mailtoplone.base.interfaces import IEventFactory

DIRECTORY = os.path.dirname(__file__)

class TestEVTGoogle(MailToPloneBaseTestCase):

    def afterSetUp(self):
        icalstr = open(os.path.join(DIRECTORY, 'data/google.ics'),'rb').read()
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(icalstr, self.folder)
        self.e = self.folder.listFolderContents()[0]

    def testEventStartDate(self):
        self.failUnless(str(self.e.startDate.toZone('UTC')) == '2007/12/04 14:30:00 Universal')

    def testEventEndDate(self):
        self.failUnless(str(self.e.endDate.toZone('UTC')) == '2007/12/04 15:30:00 Universal')

class TestEVTOwa(MailToPloneBaseTestCase):

    def afterSetUp(self):
        icalstr = open(os.path.join(DIRECTORY, 'data/owa.ics'),'rb').read()
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(icalstr, self.folder)
        self.e = self.folder.listFolderContents()[0]

    def testEventStartDate(self):
        self.failUnless(str(self.e.startDate.toZone('UTC')) == '2008/02/12 08:00:00 Universal')

    def testEventEndDate(self):
        self.failUnless(str(self.e.endDate.toZone('UTC')) == '2008/02/12 09:00:00 Universal')

    def testEventAttendees(self):
        self.failUnless(self.e.attendees == (u'MisterXXX',))

class TestEVTPlone(MailToPloneBaseTestCase):

    def afterSetUp(self):
        icalstr = open(os.path.join(DIRECTORY, 'data/plone.ics'),'rb').read()
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(icalstr, self.folder)
        self.e = self.folder.listFolderContents()[0]
    
    def testEventStartDate(self):
        self.failUnless(str(self.e.startDate.toZone('UTC')) == '2008/01/11 08:25:00 Universal')

    def testEventEndDate(self):
        self.failUnless(str(self.e.endDate.toZone('UTC')) == '2008/01/11 09:25:00 Universal')

class TestEVTRfc2445(MailToPloneBaseTestCase):

    def afterSetUp(self):
        icalstr = open(os.path.join(DIRECTORY, 'data/rfc2445.ics'),'rb').read()
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(icalstr, self.folder)
        self.e = self.folder.listFolderContents()[0]
    
    def testEventStartDate(self):
        self.failUnless(str(self.e.startDate.toZone('UTC')) == '1998/03/12 13:30:00 Universal')

    def testEventEndDate(self):
        self.failUnless(str(self.e.endDate.toZone('UTC')) == '1998/03/12 14:30:00 Universal')

class TestEVTApple(MailToPloneBaseTestCase):

    def afterSetUp(self):
        icalstr = open(os.path.join(DIRECTORY, 'data/apple.ics'),'rb').read()
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(icalstr, self.folder)
        self.e = self.folder.listFolderContents()[0]
    
    def testEventStartDate(self):
        self.failUnless(str(self.e.startDate.toZone('UTC')) == '2008/02/13 17:15:00 Universal')

    def testEventEndDate(self):
        self.failUnless(str(self.e.endDate.toZone('UTC')) == '2008/02/13 18:15:00 Universal')

    def testEventAttendees(self):
        self.failUnless(self.e.attendees == (u'Mr. X', u'Mr. Y'))

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestEVTGoogle))
    suite.addTest(unittest.makeSuite(TestEVTOwa))
    suite.addTest(unittest.makeSuite(TestEVTPlone))
    suite.addTest(unittest.makeSuite(TestEVTRfc2445))
    suite.addTest(unittest.makeSuite(TestEVTApple))
    return suite

# vim: set ft=python ts=4 sw=4 expandtab :




# -*- coding: utf-8 -*-
#
# File: test_emailview.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher <hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'

import unittest
from zope import component

from mailtoplone.base.tests.base import MailToPloneBaseTestCase
from mailtoplone.base.interfaces import IEmail
from mailtoplone.base.browser.emailview import IEmailView

class TestEmailViewSetup(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.setRoles(('Manager',))
        self.portal.invokeFactory('Email', 'm1')

    def test_emailview_registered(self):
        self.portal.m1.restrictedTraverse('view')

    def test_IEmailView_interface(self):
        self.failUnless(IEmailView.providedBy(self.portal.m1.restrictedTraverse('view')))

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestEmailViewSetup))
    return suite

# vim: set ft=python ts=4 sw=4 expandtab :




# -*- coding: utf-8 -*-
#
# File: adapter.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]


from zope import interface, component
from zope.event import notify
from zope.app.container.interfaces import INameChooser
from plone.i18n.normalizer.interfaces import IIDNormalizer
     
from Acquisition import aq_base

from mailtoplone.base.interfaces import IMailDropBox
from mailtoplone.base.events import MailDroppedEvent

class MailDropBox(object):
    """ adapts a IMailDropBoxMarker to a IMailDropBox """

    interface.implements(IMailDropBox)

    def __init__(self, context):
        self.context = context

    def drop(self, mail):
        """ drop a mail into this mail box. The mail is
        a string with the complete email content """
        
        # code unicode to utf-8
        if isinstance(mail,unicode):
            mail = mail.encode( 'utf-8' )
        type = 'Email'
        format = 'text/plain'
        content_type='text/plain'
        # generate id
        normalizer = component.getUtility(IIDNormalizer)
        chooser = INameChooser(self.context)
        id = chooser.chooseName(normalizer.normalize('email'), aq_base(self.context))
        
        self.context.invokeFactory(type ,id=id , title=id, format=format, \
                                   content_type=content_type, file=mail)
        getattr(self.context, id, None).setContentType(content_type)
        getattr(self.context, id, None).processForm()
        notify(MailDroppedEvent(getattr(self.context, id, None), self.context))
        
# vim: set ft=python ts=4 sw=4 expandtab :



# -*- coding: utf-8 -*-
#
# File: event.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]

from zope import interface
from zope import component

import email

from mailtoplone.base.interfaces import IMailDropBox
from mailtoplone.base.interfaces import IEventFactory
from mailtoplone.base.interfaces import IBodyFactory

class EventMailDropBox(object):
    """ adapts IEventMailDropBoxmarker to a IMailDropBox """

    interface.implements(IMailDropBox)

    def __init__(self, context):
        self.context = context

    def drop(self, mail):
        """ drop a mail into this mail box. The mail is
        a string with the complete email content """

        factory = component.queryUtility(IEventFactory)
        # get the body and matching content_type, charset
        bodyfactory = component.queryUtility(IBodyFactory)
        body, content_type, charset = bodyfactory(mail)
        format = content_type

        mailobj = email.message_from_string(mail)
        
        # passing the calendars to the EventFactory
        for part in mailobj.walk():
            if part.get_content_type() == 'text/calendar':
                ics = part.get_payload(decode=1)
                factory.createEvent(
                        ics,
                        self.context,
                        content_type=content_type,
                        format=format,
                        text=body
                        )

# vim: set ft=python ts=4 sw=4 expandtab :



# -*- coding: utf-8 -*-
#
# File: utilities.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]

import sys
import os
import logging

from DateTime import DateTime
from zope import component
from zope import interface
from zope import event

from zope.app.container.interfaces import INameChooser
from plone.i18n.normalizer.interfaces import IIDNormalizer

from Acquisition import aq_inner

from Acquisition import aq_base

from Products.CMFPlone.utils import getToolByName

import email
import icalendar
import dateutil

from Products.validation import validation

from Products.Archetypes.event import ObjectInitializedEvent

from mailtoplone.base import interfaces
from mailtoplone.base.myutils import dt2DT
from mailtoplone.base.events import MailDroppedEvent

class BaseDropBoxFactory(object):
    interface.implements(interfaces.IMailDropBoxFactory)

    def __call__(self, context, key):
        context = aq_inner(context)
        portal_catalog = getToolByName(context, "portal_catalog")
        brains = portal_catalog(
                id=key, 
                object_provides=interfaces.IMailDropBoxMarker.__identifier__, 
                effectiveRange=DateTime(),
                )
        for brain in brains:
            yield interfaces.IMailDropBox(brain.getObject())

class BodyFactory(object):
    interface.implements(interfaces.IBodyFactory)

    def __call__(self, mail):

        mailobj = email.message_from_string(mail)
        body_found = False
        for part in mailobj.walk():
            if part.get_content_type() == 'text/html' and not body_found:
                    body_found = True
                    body = part.get_payload(decode=1)
                    content_type = part.get_content_type()
                    charset = part.get_content_charset()

        for part in mailobj.walk():
            if part.get_content_type() == 'text/plain' and not body_found:
                    body_found = True
                    body = part.get_payload(decode=1)
                    content_type = part.get_content_type()
                    charset = part.get_content_charset()

        for part in mailobj.walk():
            if part.get_content_type() == 'text/rfc822' and not body_found:
                    body_found = True
                    body = part.get_payload(decode=1)
                    content_type = 'text/plain'
                    charset = part.get_content_charset()

        if not body_found:
                    body_found = True
                    body = ''
                    content_type = 'text/plain'
                    charset = None

        return body, content_type, charset


class ICalEventFactory(object):
    interface.implements(interfaces.IEventFactory)

    def createEvent(self, ical_str, context, **kw):

        normalizer = component.getUtility(IIDNormalizer)
        chooser = INameChooser(context)

        # get all VEVENT objects out of the ical_str
        events = []
        for eventobject in icalendar.Calendar.from_string(ical_str).walk(name='VEVENT'):
            events.append(eventobject)
            
        # extract VTIMEZONE Objects for startDate and endDate
        # 1. remove unsopported properties(X-) from ical_str
        li = ical_str.split('\n')
        clean_ical_str = "\n".join([item for item in li if not item.startswith('X-')])
        # 2. convert clean_ical_str to ical_file
        ical_file = os.tmpfile()
        ical_file.write(clean_ical_str)
        ical_file.seek(0)
        # 3. extract VTIMEZONES (there might be multiple VTIMEZONES in an calendar)
        tzones = dateutil.tz.tzical(ical_file)
        for eventobject in events:
            nkw = kw.copy()
            # generate the id
            source = 'SUMMARY'
            target = 'id'
            default = 'event'
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = chooser.chooseName(normalizer.normalize(default), aq_base(context))
                else:
                    nkw[target] = chooser.chooseName(normalizer.normalize(eventobject.decoded(source)), aq_base(context))
            else:
                nkw[target] = chooser.chooseName(normalizer.normalize(nkw[target]), aq_base(context))
 
            # generate the title
            source = 'SUMMARY'
            target = 'title'
            default = 'unnamed event'
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = default
                else:
                    nkw[target] = eventobject.decoded(source)
            
            # generate the description
            source = 'DESCRIPTION'
            target = 'description'
            default = ''
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = default
                else:
                    nkw[target] = eventobject.decoded(source)
            
            # generate the location
            source = 'LOCATION'
            target = 'location'
            default = ''
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = default
                else:
                    nkw[target] = eventobject.decoded(source)

            # generate the eventUrl
            source = 'URL'
            target = 'eventUrl'
            default = ''
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = default
                else:
                    nkw[target] = eventobject.decoded(source)

            # generate the eventType
            source = 'CATEGORIES'
            target = 'eventType'
            default = ''
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    nkw[target] = default
                else:
                    nkw[target] = eventobject.get(source).split(",")

            # generate the startDate
            source = 'DTSTART'
            target = 'startDate'
            if not target in nkw.keys():
                if source in eventobject.keys():
                    if eventobject[source].params.has_key('TZID'):
                        tzone = tzones.get(eventobject[source].params['TZID'])
                        gmt_time = dt2DT(eventobject.decoded(source).replace(tzinfo=tzone))
                    else:
                        gmt_time = dt2DT(eventobject.decoded(source))
                    nkw[target] = gmt_time.toZone(gmt_time.localZone())

             # generate the endDate, it might be specified as DTEND, or as DTSTART + DURATION
            source = 'DTEND'
            source2 = 'DURATION'
            target = 'endDate'
            if not target in nkw.keys():
                if not source in eventobject.keys():
                    if 'DTSTART' in eventobject.keys() and source2 in eventobject.keys():
                        if eventobject['DTSTART'].params.has_key('TZID'):
                            tzone = tzones.get(eventobject['DTSTART'].params['TZID'])
                            gmt_time = dt2DT(eventobject.decoded('DTSTART').replace(tzinfo=tzone) + eventobject.decoded(source2))
                        else:
                            gmt_time = dt2DT(eventobject.decoded(DTSTART)+eventobject.decoded(source2))
                        nkw[target] = gmt_time.toZone(gmt_time.localZone())
                else:
                    if eventobject[source].params.has_key('TZID'):
                        tzone = tzones.get(eventobject[source].params['TZID'])
                        gmt_time = dt2DT(eventobject.decoded(source).replace(tzinfo=tzone))
                    else:
                        gmt_time = dt2DT(eventobject.decoded(source))
                    nkw[target] = gmt_time.toZone(gmt_time.localZone())

            # generate the contact fields
            source = 'CONTACT'
            clist = []
            if source in eventobject.keys():
                clist = eventobject.get(source).split(", ")
            
            # contact Email
            target = 'contactEmail'
            v = validation.validatorFor('isEmail')
            if not target in nkw.keys():
                    for elem in clist:
                        if v(str(elem)) == True:
                            nkw[target] = elem
                            clist.remove(elem)
                            break

            # contact phone
            target = 'contactPhone'
            v = validation.validatorFor('isInternationalPhoneNumber')
            if not target in nkw.keys():
                    for elem in clist:
                        if v(str(elem), ignore='[\\\(\)\-\s\+\/]') == True:
                            nkw[target] = elem
                            clist.remove(elem)
                            break
                    if (not target in nkw.keys()) and (len(clist) > 1):
                        nkw[target] = clist[1]
                        clist.remove(elem)
 
         # contact name
            target = 'contactName'
            if not target in nkw.keys():
                    for elem in clist:
                            nkw[target] = elem
                            break

         # attendees
         # There can be multiple "ATTENDEE" properties inside an VEVENT, the icalendar library returns a list of
         # vCalAddress objects if so, or otherwise a single vCalAddress object
         # we'll extract the CN (common name) if there is one inside and use it as an entry in the attendees linesfield
            source = 'ATTENDEE'
            target = 'attendees'
            if not target in nkw.keys():
                if source in eventobject.keys():
                    adrobjs = eventobject.get(source)
                    if type(adrobjs) == list:
                       nkw[target] = [item.params['CN'] for item in adrobjs if item.params.has_key('CN')]
                    elif adrobjs.params.has_key('CN'):
                       nkw[target] = [adrobjs.params['CN']]

            _ = context.invokeFactory("Event", **nkw)
            event.notify(ObjectInitializedEvent(getattr(context, nkw['id'], None)))
            event.notify(MailDroppedEvent(getattr(context, nkw['id'], None), context))

        return context.get(_)


# vim: set ft=python ts=4 sw=4 expandtab :



"""Definition of the InBox content type
"""

from zope.interface import implements, directlyProvides

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder

from Products.ATContentTypes.content import schemata
from Products.ATContentTypes.content.schemata import finalizeATCTSchema

from mailtoplone.base import baseMessageFactory as _
from mailtoplone.base.interfaces import IInBox, IMailDropBoxMarker
from mailtoplone.base.config import PROJECTNAME

InBoxSchema = folder.ATFolderSchema.copy() + atapi.Schema((

# Your Archetypes field definitions here ...

))

# Set storage on fields copied from ATFolder, making sure they work
# well with the python bridge properties.

InBoxSchema['title'].storage = atapi.AnnotationStorage()
InBoxSchema['description'].storage = atapi.AnnotationStorage()

finalizeATCTSchema(InBoxSchema, folderish=True, moveDiscussion=False)

class InBox(folder.ATFolder):
    """A folderish type containing Emails"""
    implements(IInBox, IMailDropBoxMarker)

    portal_type = "InBox"
    _at_rename_after_creation = True
    schema = InBoxSchema

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')
    
atapi.registerType(InBox, PROJECTNAME)



"""Definition of the Email content type
"""

from zope.interface import implements, directlyProvides

from Products.Archetypes import atapi
from Products.ATContentTypes.content import file

from Products.ATContentTypes.content import schemata
from Products.ATContentTypes.content.schemata import finalizeATCTSchema

from mailtoplone.base import baseMessageFactory as _
from mailtoplone.base.interfaces import IEmail
from mailtoplone.base.config import PROJECTNAME

EmailSchema = file.ATFileSchema.copy() + atapi.Schema((

# Your Archetypes field definitions here ...

))

# Set storage on fields copied from ATContentTypeSchemata, making sure 
# they work well with the python bridge properties.

EmailSchema['title'].storage = atapi.AnnotationStorage()
EmailSchema['description'].storage = atapi.AnnotationStorage()

finalizeATCTSchema(EmailSchema, moveDiscussion=False)

class Email(file.ATFile):
    """A file like content containing an email"""
    implements(IEmail)

    portal_type = "Email"
    _at_rename_after_creation = True
    schema = EmailSchema

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')
    
atapi.registerType(Email, PROJECTNAME)



# -*- coding: utf-8 -*-
#
# File: interfaces.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]


from zope import component
from zope import interface
from zope import schema


from zope.app.container.constraints import contains
from zope.app.container.constraints import containers


from mailtoplone.base import baseMessageFactory as _

# Interfaces go here ...
# -*- extra stuff goes here -*-

class IInBox(interface.Interface):
    """A folderish type containing Emails"""

class IEmail(interface.Interface):
    """A file like content containing an email"""

# SELETZ
class IMailDropBoxMarker(interface.Interface):
    """ marker interface for mail drop boxes """

class IMailDropBox(interface.Interface):
    """ a mail drop box """
    def drop(mail):
        """ drop a mail into this mail box. The mail is
            a string with the complete email content """

class IMailDropBoxFactory(interface.Interface):
    """ a factory for mail drop boxes """

    def __call__(context, key):
        """ look up drop boxes based on context and key, and return a list of
        objects providing IMailDropBox """
# /SELETZ

class IBlogMailDropBoxMarker(IMailDropBoxMarker):
    """ marker interface for blog mail drop boxes """

class IEventMailDropBoxMarker(IMailDropBoxMarker):
    """ marker interface for event mail drop boxes """

class IEventFactory(interface.Interface):
    """ creates a AT Event out of something. Keyword args
        are passed to invokeFactory() """

    def createEvent(source, context, **kwargs ):
        """ create a event in some context """

__doc__ = """
    >>> event_dict_with_atevent_keys = {} # leeres dict
    >>> event_dict_with_atevent_keys.update(kwargs) # dict mit default von user füllen
    >>> utils.icalparse(icalobj, event_dict_with_atevent_keys) # dict weiter füllen mit ical stuff
    >>> _ = self.folder.invokeFactory("ATEvent", "evt", **event_dict_with_atevent_keys ) # create atevent
    >>> obj = self.folder.get(_)

    ...

    >>> kw = dict( title="zonk", hurz="muha", body=file("/tmp/xxx").read() )
    >>> obj.update( **kw )

    ... 

"""

class IICalEventFactory(IEventFactory):
    """ iCal Object to AT Event factory """

    def createEvent(icalevt, context, **kwargs ):
        """ creates an AT Event out of an iCal object """

class IBodyFactory(interface.Interface):
    """ extract a body and a content_type from a mail string"""

    def __call__(mail):
        """ go through mail and return a body and a content_type """

class IMailDroppedEvent(component.interfaces.IObjectEvent):
    object = interface.Attribute("The mail object of the event.")
    context = interface.Attribute("The context of the event.")

# vim: set ft=python ts=4 sw=4 expandtab :



# -*- coding: utf-8 -*-
#
# File: emailview.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]

import email
from email.Header import decode_header
import urllib

from zope.interface import implements, Interface
from zope import component

from Products.Five import BrowserView
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from Products.Archetypes.utils import contentDispositionHeader

from plone.memoize.instance import memoize

from mailtoplone.base import baseMessageFactory as _
from mailtoplone.base.interfaces import IEmail
from mailtoplone.base.interfaces import IBodyFactory

class IEmailView(Interface):
    """
      EmailView interface
    """

    def test():
        """ test method"""



class EmailView(BrowserView):
    """
    EmailView for having a nice representation of the Email
    """
    implements(IEmailView)

    def __init__(self, context, request):
        self.context = context
        self.request = request

    render = ViewPageTemplateFile('emailview.pt')

    def __call__(self):
        return self.render()

    @property
    def title(self):
        return self.context.title

    def decodeheader(self, header_text, default="ascii"):
        """Decode the specified header"""
        headers = decode_header(header_text)
        header_sections = [unicode(text, charset or default)
                       for text, charset in headers]
        return u"".join(header_sections)

    @memoize
    def headers(self):
        """
        returns a list of dicts like::

        [ { name="Subject", items=["muh", "mah"] }

        """
        headerlist = ['Subject','From','To','CC']
        adressheaders = headerlist[1:]
        m = email.message_from_string(self.context.data)
        for name in headerlist:
            if m.has_key(name):
                decoded = self.decodeheader(m[name])
                if name in adressheaders:
                    yield dict( name=name, contents=decoded.split(', ') )
                else:
                    yield dict( name=name, contents=[decoded] )


    def attachments(self):
        """return a generator which yields dicts like
            { "mimetype": "text/plain",
              "id":       "someidwhichisunique",
              "filename": "muha.txt" }
        """
        # we'll make an attachment for every part of the mail which has a
        # filename parameter
        m = email.message_from_string(self.context.data)
        parts = [item for item in m.walk() if item.get_filename() != None]
        for index, elem in enumerate(parts):
            charset = elem.get_content_charset() or "ISO-8859-1"
            mimetype= elem.get_content_type().decode(charset).encode("ascii", "ignore")
            fn= elem.get_filename().decode(charset).encode("ascii", "ignore")
            id = index
            url="%s/@@download?download=%s&mimetype=%s&filename=%s" % (
                self.context.absolute_url(),
                id,
                urllib.quote(mimetype),
                urllib.quote(fn) )
            yield dict(
                    mimetype=mimetype,
                    filename=fn,
                    id=id,
                    download_url=url
                    )

    @memoize
    def body(self):
        bodyfactory = component.getUtility(IBodyFactory)
        body, content_type, charset = bodyfactory(self.context.data)
        try:
            body = body.decode(charset).encode('utf-8')
        except (LookupError, TypeError):
            pass

        return dict(
                text=body,
                content_type=content_type,
                charset=charset,
                formatted=content_type == "text/html",
        )


    def test(self):
        """ 
        test method 
        """
        dummy = _(u'a dummy string')

        return {'dummy': dummy}


class AttachmentDownload(BrowserView):
    def __init__(self, context, request):
        self.context = context
        self.request = request

    def __call__(self):
        if self.request.get("download", None) is None:
            request.RESPONSE.redirect(self.context.absolute_url())

        m = email.message_from_string(self.context.data)
        parts = [item for item in m.walk() if item.get_filename() != None]
        if parts[int(self.request.get("download"))].is_multipart():
            data = str(parts[int(self.request.get("download"))])
        else:
            data = parts[int(self.request.get("download"))].get_payload(decode=1)
        REQUEST = self.request
        RESPONSE = REQUEST.RESPONSE
        filename = REQUEST.get("filename")
        mimetype = REQUEST.get("mimetype")
        if filename is not None:
            header_value = contentDispositionHeader(
                disposition='attachment',
                filename=filename)
            RESPONSE.setHeader("Content-disposition", header_value)
            RESPONSE.setHeader("Content-Type", mimetype)
        return data


# vim: set ft=python ts=4 sw=4 expandtab :



# -*- coding: utf-8 -*-
#
# File: blog.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]

import email
import logging

from zope import interface
from zope import component
from zope.event import notify

from zope.app.container.interfaces import INameChooser
from plone.i18n.normalizer.interfaces import IIDNormalizer

from Acquisition import aq_base

from mailtoplone.base.interfaces import IMailDropBox
from mailtoplone.base.interfaces import IBodyFactory
from mailtoplone.base.events import MailDroppedEvent

info = logging.getLogger().info

class BlogMailDropBox(object):
    """ adapts IBlogMailDropBoxmarker to a IMailDropBox """

    interface.implements(IMailDropBox)

    def __init__(self, context):
        self.context = context

    def drop(self, mail):
        """ drop a mail into this mail box. The mail is
        a string with the complete email content """
        
        # get the body and matching content_type, charset
        bodyfactory = component.queryUtility(IBodyFactory)
        body, content_type, charset = bodyfactory(mail)
        format = content_type

        mailobj = email.message_from_string(mail)

        # Subject and description
        for key in "Subject subject Betreff x-blog-title".split():
            subject = mailobj.get(key)
            if subject is not None:
                break
        description = mailobj.get("x-blog-description", "")

        info( "BlogMailDropBox: new mail with subject '%s'" % subject )

        # XXX: the namechooer does a getattr('check_id'), which results in a python
        #      script (!!) which is aquired. That script makes the name chooser not choose
        #      correctly, thus we strip acquisition. Bah.
        normalizer = component.getUtility(IIDNormalizer)
        chooser = INameChooser(self.context)
        id = chooser.chooseName(normalizer.normalize(subject), aq_base(self.context))

        self.context.invokeFactory(
                'News Item',
                id=id,
                title=subject,
                format=format,
                content_type=content_type,
                description=description,
                text=body
                )

        news = getattr(self.context, id)
        news.processForm()
        notify(MailDroppedEvent(news, self.context))

# vim: set ft=python ts=4 sw=4 expandtab :



# -*- coding: utf-8 -*-
#
# File: test_setup.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher <hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'

import unittest
from zope import component

from mailtoplone.base.tests.base import MailToPloneBaseTestCase
from mailtoplone.base.interfaces import IInBox, IEmail, IMailDropBoxMarker, IMailDropBox
from mailtoplone.base.browser.xmlrpcview import IXMLRPCView
from Products.CMFCore.utils import getToolByName

class TestSetup(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.types = getToolByName(self.portal, 'portal_types')
        self.setRoles(('Manager',))
        self.portal.invokeFactory('InBox', 'inbox')
        self.portal.inbox.invokeFactory('Email', 'email')

    def test_mailtoplone_base_Email_installed(self):
        self.failUnless('Email' in self.types.objectIds())

    def test_mailtoplone_base_InBox_installed(self):
        self.failUnless('InBox' in self.types.objectIds())

    def test_IEmail_interface(self):
        self.failUnless(IEmail.providedBy(self.portal.inbox.email))

    def test_IInBox_interface(self):
        self.failUnless(IInBox.providedBy(self.portal.inbox))

    def test_IMailDropBoxMarker_interface(self):
        self.failUnless(IInBox.providedBy(self.portal.inbox))

    def test_Email_add_permisison(self):
        # The API of the permissionsOfRole() function sucks - it is bound too
        # closely up in the permission management screen's user interface
        self.failUnless('mailtoplone.base: Add Email' in [r['name'] for r in 
                                self.portal.permissionsOfRole('Manager') if r['selected']])
    def test_InBox_add_permisison(self):
        # The API of the permissionsOfRole() function sucks - it is bound too
        # closely up in the permission management screen's user interface
        self.failUnless('mailtoplone.base: Add InBox' in [r['name'] for r in 
                                self.portal.permissionsOfRole('Manager') if r['selected']])

    def test_Email_global_addable(self):
        result = True
        import sys
        try:
            self.portal.invokeFactory('Email','email2')
        except ValueError:
            if sys.exc_info()[1].__str__() == 'Disallowed subobject type: Email':
                result = False

        self.failUnless(result)

    def test_IMailDropBoxMarker_IMailDropBox_Adapter(self):
        self.failUnless(IMailDropBox(self.portal.inbox, None))

    def test_xmlrpcview_registered(self):
        self.portal.inbox.restrictedTraverse('xmlrpcview')
    
    def test_IXMLRPCView_interface(self):
        self.failUnless(IXMLRPCView.providedBy(self.portal.inbox.restrictedTraverse('xmlrpcview')))

def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestSetup))
    return suite

# vim: set ft=python ts=4 sw=4 expandtab :




# -*- coding: utf-8 -*-
#
# File: test_eventfactory.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Hans-Peter Locher <hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'

import unittest
from zope import component
from zope.component import adapter

from Products.Archetypes.interfaces import IObjectInitializedEvent

from mailtoplone.base.tests.base import MailToPloneBaseTestCase
from mailtoplone.base.interfaces import IEventFactory

ICALSTR="""
BEGIN:VCALENDAR
PRODID:-//AT Content Types//AT Event//EN
VERSION:2.0
METHOD:PUBLISH
BEGIN:VEVENT
DTSTAMP:20080111T082529Z
CREATED:20080111T082344Z
UID:ATEvent-7a6801e8dda74e3af2216e5570ae2564
LAST-MODIFIED:20080111T082344Z
SUMMARY:eventtitle
DTSTART:20080111T082500Z
DTEND:20080111T092500Z
DESCRIPTION:eventdescription
LOCATION:eventlocation
CATEGORIES:another event category,an event category
CONTACT:event contact name\, 1223498765\, eventcontactemail@hurz.de
URL:http://www.eventurl.de
CLASS:PUBLIC
END:VEVENT
END:VCALENDAR
"""
MULTICALSTR="""
BEGIN:VCALENDAR
PRODID:-//AT Content Types//AT Event//EN
VERSION:2.0
METHOD:PUBLISH
BEGIN:VEVENT
DTSTAMP:20080111T082529Z
CREATED:20080111T082344Z
UID:ATEvent-7a6801e8dda74e3af2216e5570ae2564
LAST-MODIFIED:20080111T082344Z
SUMMARY:eventtitle
DTSTART:20080111T082500Z
DTEND:20080111T092500Z
DESCRIPTION:eventdescription
LOCATION:eventlocation
CATEGORIES:another event category,an event category
CONTACT:event contact name\, 1223498765\, eventcontactemail@hurz.de
URL:http://www.eventurl.de
CLASS:PUBLIC
END:VEVENT
BEGIN:VEVENT
DTSTAMP:20080111T082529Z
CREATED:20080111T082344Z
UID:ATEvent-7a6801e8dda74e3af2216e5570ae2564
LAST-MODIFIED:20080111T082344Z
SUMMARY:differenteventtitle
DTSTART:20080111T082500Z
DTEND:20080111T092500Z
DESCRIPTION:eventdescription
LOCATION:eventlocation
CATEGORIES:another event category,an event category
CONTACT:event contact name\, 1223498765\, eventcontactemail@hurz.de
URL:http://www.eventurl.de
CLASS:PUBLIC
END:VEVENT
END:VCALENDAR
"""

class TestEVTFactory(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.setRoles(('Manager',))

    def testUtilityLookup(self):
        self.failUnless(component.queryUtility(IEventFactory))

    def testFactoryCreatesATEvent(self):
        factory = component.queryUtility(IEventFactory)
        self.failUnless(factory.createEvent(ICALSTR, self.folder))
        self.failUnless("eventtitle" in self.folder.objectIds())

    def testFactoryPassesText(self):
        factory = component.queryUtility(IEventFactory)
        self.failUnless(factory.createEvent(ICALSTR, self.folder, text="thetext"))
        self.failUnless("<p>thetext</p>" == self.folder.eventtitle.getText())

class TestEVTFields(MailToPloneBaseTestCase):
    """ note: startDate and endDate are tested seperately in test_eventfactory_time.py """

    def afterSetUp(self):
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(ICALSTR, self.folder)

    def testEventTitle(self):
        self.failUnless(self.folder.eventtitle.title == "eventtitle")

    def testEventDescription(self):
        self.failUnless(self.folder.eventtitle.Description() == "eventdescription")

    def testEventLocation(self):
        self.failUnless(self.folder.eventtitle.location == "eventlocation")

    def testEventURL(self):
        self.failUnless(self.folder.eventtitle.eventUrl == "http://www.eventurl.de")

    def testEventType(self):
        self.failUnless(self.folder.eventtitle.eventType == (u'another event category', u'an event category'))

    def testEventContactName(self):
        self.failUnless(self.folder.eventtitle.contactName == u'event contact name')
        
    def testEventContactEmail(self):
        self.failUnless(self.folder.eventtitle.contactEmail == u'eventcontactemail@hurz.de')

    def testEventContactPhone(self):
        self.failUnless(self.folder.eventtitle.contactPhone == u'1223498765')

class TestEVTMult(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.setRoles(('Manager',))
        factory = component.queryUtility(IEventFactory)
        factory.createEvent(MULTICALSTR, self.folder)

    def testNumContents(self):
        self.failUnless(len(self.folder.objectIds()) == 2)

    def testEventsDiffer(self):
        e1 = self.folder.listFolderContents()[0]
        e2 = self.folder.listFolderContents()[1]
        self.failUnless(e1.title != e2.title)


class TestEVTInitialization(MailToPloneBaseTestCase):

    def afterSetUp(self):
        self.setRoles(('Manager',))
        self.factory = component.queryUtility(IEventFactory)

    def testEVTObjectInitializedEvent(self):
        self.sourceObject = None
        @adapter(IObjectInitializedEvent)
        def setSourceObject(new_event):
            self.sourceObject = new_event.object
        
        component.provideHandler(setSourceObject)
        self.factory.createEvent(ICALSTR, self.folder)
        self.failUnless(self.folder.listFolderContents()[0] == self.sourceObject)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestEVTFactory))
    suite.addTest(unittest.makeSuite(TestEVTFields))
    suite.addTest(unittest.makeSuite(TestEVTMult))
    suite.addTest(unittest.makeSuite(TestEVTInitialization))
    return suite

# vim: set ft=python ts=4 sw=4 expandtab :




# -*- coding: utf-8 -*-
#
# File: __init__.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
""" additional adapters for mailtoplone """

__author__    = """Hans-Peter Locher<hans-peter.locher@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 36831 $"
__version__   = '$Revision: 1.7 $'[11:-2]

# vim: set ft=python ts=4 sw=4 expandtab :



"""Common configuration constants
"""

PROJECTNAME = "mailtoplone.base"

ADD_PERMISSIONS = { 
	# -*- extra stuff goes here -*-

   "InBox"  :  "mailtoplone.base: Add InBox",

   "Email"  :  "mailtoplone.base: Add Email",
	}



# -*- coding: utf-8 -*-
#
# File: events.py
#
# Copyright (c) InQuant GmbH
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

__author__    = """Stefan Eletzhofer <stefan.eletzhofer@inquant.de>"""
__docformat__ = 'plaintext'
__revision__  = "$Revision: 61041 $"
__version__   = '$Revision: 61041 $'[11:-2]

from zope import interface
from zope import component

from plone.app.contentrules.handlers import execute

from mailtoplone.base.interfaces import IMailDroppedEvent

class MailDroppedEvent(object):
    interface.implements(IMailDroppedEvent)

    def __init__(self, object, context):
        self.object = object
        self.context = context

def maildropped(event):
    execute(event.context, event)


# vim: set ft=python ts=4 sw=4 expandtab :



from setuptools import setup, find_packages

version = '0.2.3'

setup(name='mailtoplone.base',
      version=version,
      description="basic package for mailtoplone",
      long_description=file("README.txt").read(),
      # Get more strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Framework :: Plone",
        "Framework :: Zope2",
        "Framework :: Zope3",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        ],
      keywords='',
      author='Hans-Peter Locher',
      author_email='hans-peter.locher@inquant.de',
      url='https://svn.plone.org/svn/collective/mailtoplone/mailtoplone.base',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['mailtoplone'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'icalendar',
          'dateutil',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )
